EstimationResult
================

.. currentmodule:: pqp.estimation

.. autoclass:: EstimationResult
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~EstimationResult.keys

   .. rubric:: Attributes Documentation

   .. autoattribute:: keys
